@@ -6,7 +6,7 @@ import jsonschema
 
 import yaml
 
-from .schema import validator, default_filler
+from .schema import default_filler, validator
 
 
 def schema_violations_from_proposed_config(config: Dict) -> List[str]:
@@ -33,7 +33,6 @@ class TestlibConfig(dict):
         # fill defaults not specified by user
         default_filler.validate(d)
 
-
     def __str__(self) -> str:
         return repr(self)
 
